![builds](https://github.com/danforthcenter/plantcv/workflows/builds/badge.svg)
[![DeepSource](https://app.deepsource.com/gh/danforthcenter/plantcv.svg/?label=code+coverage&show_trend=true&token=og8rSyKxywOCGkIk8UNiF7B_)](https://app.deepsource.com/gh/danforthcenter/plantcv/)
[![DeepSource](https://app.deepsource.com/gh/danforthcenter/plantcv.svg/?label=active+issues&show_trend=true&token=og8rSyKxywOCGkIk8UNiF7B_)](https://app.deepsource.com/gh/danforthcenter/plantcv/)
[![Documentation Status](https://readthedocs.org/projects/plantcv/badge/?version=stable)](https://plantcv.readthedocs.io/en/stable/?badge=stable)
[![GitHub release](https://img.shields.io/github/release/danforthcenter/plantcv.svg)](https://github.com/danforthcenter/plantcv/releases)
[![PyPI version](https://badge.fury.io/py/plantcv.svg)](https://badge.fury.io/py/plantcv)
![Conda](https://img.shields.io/conda/v/conda-forge/plantcv)
[![license](https://img.shields.io/github/license/danforthcenter/plantcv.svg)](https://github.com/danforthcenter/plantcv/blob/main/LICENSE)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](docs/CODE_OF_CONDUCT.md)
<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-71-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

# PlantCV: Plant phenotyping using computer vision

Please use, cite, and [contribute to](http://plantcv.readthedocs.io/en/latest/CONTRIBUTING/) PlantCV!
If you have questions, please submit them via the
[GitHub issues page](https://github.com/danforthcenter/plantcv/issues).
Follow us on twitter [@plantcv](https://twitter.com/plantcv).

***

## Introduction to PlantCV

PlantCV is an open-source image analysis software package targeted for plant phenotyping. PlantCV provides a common
programming and documentation interface to a collection of image analysis techniques that are integrated from a variety
of source packages and algorithms. PlantCV utilizes a modular architecture that enables flexibility in the design of
analysis workflows and rapid assimilation and integration of new methods. For more information about the project,
links to recorded presentations, and publications using PlantCV, please visit our homepage: 
<https://plantcv.danforthcenter.org/>.

### Quick Links

* [Documentation](http://plantcv.readthedocs.io/)
* [Tutorial Gallery](https://plantcv.org/tutorials)
* [Installation Instructions](https://plantcv.readthedocs.io/en/stable/installation/)
* [Updating/Changelog](https://plantcv.readthedocs.io/en/stable/updating/)
* [Public Image Datasets](https://datasci.danforthcenter.org/data/)
* [Contribution Guide](https://plantcv.readthedocs.io/en/stable/CONTRIBUTING/)
* [Code of Conduct](https://plantcv.readthedocs.io/en/stable/CODE_OF_CONDUCT/)
* Downloads
  * [GitHub](https://github.com/danforthcenter/plantcv)
  * [PyPI](https://pypi.org/project/plantcv/)
  * [Conda-forge](https://anaconda.org/conda-forge/plantcv)
  * [Zenodo](https://doi.org/10.5281/zenodo.595522)

### Citing PlantCV

If you use PlantCV, please cite the [PlantCV publications](https://plantcv.danforthcenter.org/#plantcv-publications)
relevant to your work. To see how others have used PlantCV in their research, check out our list of 
[publications using PlantCV](https://plantcv.danforthcenter.org/#publications-using-plantcv).

***

## Issues with PlantCV

Please file any PlantCV suggestions/issues/bugs via our 
[GitHub issues page](https://github.com/danforthcenter/plantcv/issues). Please check to see if any related 
issues have already been filed.

***

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/AFis-245"><img src="https://avatars.githubusercontent.com/u/145135602?v=4?s=100" width="100px;" alt="AFis-245"/><br /><sub><b>AFis-245</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=AFis-245" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://www.adonline.id.au/"><img src="https://avatars.githubusercontent.com/u/5926320?v=4?s=100" width="100px;" alt="Adam Dimech"/><br /><sub><b>Adam Dimech</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=AdamDimech" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=AdamDimech" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=AdamDimech" title="Tests">⚠️</a> <a href="#ideas-AdamDimech" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://alexanderkutschera.com/"><img src="https://avatars.githubusercontent.com/u/20026476?v=4?s=100" width="100px;" alt="Alexander Kutschera"/><br /><sub><b>Alexander Kutschera</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=vektorious" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=vektorious" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=vektorious" title="Tests">⚠️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/aapokor"><img src="https://avatars.githubusercontent.com/u/39534960?v=4?s=100" width="100px;" alt="Alexandria Pokorny"/><br /><sub><b>Alexandria Pokorny</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=aapokor" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=aapokor" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=aapokor" title="Tests">⚠️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/AzlinII"><img src="https://avatars.githubusercontent.com/u/15007726?v=4?s=100" width="100px;" alt="Andy Lin"/><br /><sub><b>Andy Lin</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=AzlinII" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/caitlynelliott56"><img src="https://avatars.githubusercontent.com/u/214695433?v=4?s=100" width="100px;" alt="Caitlyn Elliott"/><br /><sub><b>Caitlyn Elliott</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=caitlynelliott56" title="Code">💻</a> <a href="#ideas-caitlynelliott56" title="Ideas, Planning, & Feedback">🤔</a> <a href="#tutorial-caitlynelliott56" title="Tutorials">✅</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://calizarr.github.io/resume"><img src="https://avatars.githubusercontent.com/u/3262069?v=4?s=100" width="100px;" alt="Cesar Lizarraga"/><br /><sub><b>Cesar Lizarraga</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=calizarr" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=calizarr" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=calizarr" title="Tests">⚠️</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/clhendrikse"><img src="https://avatars.githubusercontent.com/u/70405404?v=4?s=100" width="100px;" alt="Chloe Hendrikse"/><br /><sub><b>Chloe Hendrikse</b></sub></a><br /><a href="#tutorial-clhendrikse" title="Tutorials">✅</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=clhendrikse" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/cluebbert"><img src="https://avatars.githubusercontent.com/u/47461392?v=4?s=100" width="100px;" alt="Collin Luebbert"/><br /><sub><b>Collin Luebbert</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=cluebbert" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://www.linkedin.com/in/david-peery-344882126/"><img src="https://avatars.githubusercontent.com/u/63679152?v=4?s=100" width="100px;" alt="David Peery"/><br /><sub><b>David Peery</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=jdavidpeery" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=jdavidpeery" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=jdavidpeery" title="Tests">⚠️</a> <a href="#ideas-jdavidpeery" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/dhiraj-ms"><img src="https://avatars.githubusercontent.com/u/39856917?v=4?s=100" width="100px;" alt="Dhiraj Srivastava"/><br /><sub><b>Dhiraj Srivastava</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=dhiraj-ms" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=dhiraj-ms" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=dhiraj-ms" title="Tests">⚠️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://data-folks.masto.host/@dschneiderch"><img src="https://avatars.githubusercontent.com/u/7461221?v=4?s=100" width="100px;" alt="Dominik Schneider"/><br /><sub><b>Dominik Schneider</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=dschneiderch" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=dschneiderch" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=dschneiderch" title="Tests">⚠️</a> <a href="#ideas-dschneiderch" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://rayngrowingsystems.com/"><img src="https://avatars.githubusercontent.com/u/129968640?v=4?s=100" width="100px;" alt="Dr. Alexander Kutschera"/><br /><sub><b>Dr. Alexander Kutschera</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=rayn-alex" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/issues?q=author%3Arayn-alex" title="Bug reports">🐛</a> <a href="#question-rayn-alex" title="Answering Questions">💬</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/emmanuel-ferdman"><img src="https://avatars.githubusercontent.com/u/35470921?v=4?s=100" width="100px;" alt="Emmanuel Ferdman"/><br /><sub><b>Emmanuel Ferdman</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/issues?q=author%3Aemmanuel-ferdman" title="Bug reports">🐛</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=emmanuel-ferdman" title="Documentation">📖</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ic"><img src="https://avatars.githubusercontent.com/u/64160?v=4?s=100" width="100px;" alt="Eric Platon"/><br /><sub><b>Eric Platon</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=ic" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=ic" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=ic" title="Tests">⚠️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://www.datamaplab.com"><img src="https://avatars.githubusercontent.com/u/2442821?v=4?s=100" width="100px;" alt="Fabian Dubois"/><br /><sub><b>Fabian Dubois</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=fabid" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://fabiobarbero.eu"><img src="https://avatars.githubusercontent.com/u/20724986?v=4?s=100" width="100px;" alt="Fabio Barbero"/><br /><sub><b>Fabio Barbero</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=fbarbe00" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ygarrot"><img src="https://avatars.githubusercontent.com/u/33935239?v=4?s=100" width="100px;" alt="Garrot Yoan"/><br /><sub><b>Garrot Yoan</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=ygarrot" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/GrantKonkel"><img src="https://avatars.githubusercontent.com/u/78433847?v=4?s=100" width="100px;" alt="GrantKonkel"/><br /><sub><b>GrantKonkel</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=GrantKonkel" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=GrantKonkel" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/HaleySchuhl"><img src="https://avatars.githubusercontent.com/u/44006936?v=4?s=100" width="100px;" alt="Haley Schuhl"/><br /><sub><b>Haley Schuhl</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=HaleySchuhl" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=HaleySchuhl" title="Documentation">📖</a> <a href="#maintenance-HaleySchuhl" title="Maintenance">🚧</a> <a href="#tutorial-HaleySchuhl" title="Tutorials">✅</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=HaleySchuhl" title="Tests">⚠️</a> <a href="#talk-HaleySchuhl" title="Talks">📢</a> <a href="#ideas-HaleySchuhl" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-HaleySchuhl" title="Answering Questions">💬</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/hkmanching"><img src="https://avatars.githubusercontent.com/u/8751385?v=4?s=100" width="100px;" alt="Heather Manching"/><br /><sub><b>Heather Manching</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/issues?q=author%3Ahkmanching" title="Bug reports">🐛</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/DannieSheng"><img src="https://avatars.githubusercontent.com/u/28633120?v=4?s=100" width="100px;" alt="Hudanyun Sheng"/><br /><sub><b>Hudanyun Sheng</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=DannieSheng" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=DannieSheng" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=DannieSheng" title="Tests">⚠️</a> <a href="#ideas-DannieSheng" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://jakejasper.xyz"><img src="https://avatars.githubusercontent.com/u/35571955?v=4?s=100" width="100px;" alt="Jake"/><br /><sub><b>Jake</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=Jake-Jasper" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=Jake-Jasper" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/JalissaPirro"><img src="https://avatars.githubusercontent.com/u/214848039?v=4?s=100" width="100px;" alt="JalissaPirro"/><br /><sub><b>JalissaPirro</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=JalissaPirro" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=JalissaPirro" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/jberry47"><img src="https://avatars.githubusercontent.com/u/20114985?v=4?s=100" width="100px;" alt="Jeffrey Berry"/><br /><sub><b>Jeffrey Berry</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=jberry47" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=jberry47" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=jberry47" title="Tests">⚠️</a> <a href="#ideas-jberry47" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/JoeDuenwald"><img src="https://avatars.githubusercontent.com/u/101900627?v=4?s=100" width="100px;" alt="JoeDuenwald"/><br /><sub><b>JoeDuenwald</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=JoeDuenwald" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://sites.google.com/view/jorge-gutierrezor/home"><img src="https://avatars.githubusercontent.com/u/26798565?v=4?s=100" width="100px;" alt="Jorge Gutierrez"/><br /><sub><b>Jorge Gutierrez</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=JorgeGtz" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=JorgeGtz" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=JorgeGtz" title="Tests">⚠️</a> <a href="#talk-JorgeGtz" title="Talks">📢</a> <a href="#ideas-JorgeGtz" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-JorgeGtz" title="Answering Questions">💬</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/joshqsumner"><img src="https://avatars.githubusercontent.com/u/51797700?v=4?s=100" width="100px;" alt="Josh Sumner"/><br /><sub><b>Josh Sumner</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=joshqsumner" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=joshqsumner" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=joshqsumner" title="Tests">⚠️</a> <a href="#tutorial-joshqsumner" title="Tutorials">✅</a> <a href="#ideas-joshqsumner" title="Ideas, Planning, & Feedback">🤔</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/kaitlynrying"><img src="https://avatars.githubusercontent.com/u/156353832?v=4?s=100" width="100px;" alt="Kaitlyn Ying"/><br /><sub><b>Kaitlyn Ying</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=kaitlynrying" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://www.danforthcenter.org/our-work/core-facilities/phenotyping/"><img src="https://avatars.githubusercontent.com/u/58490237?v=4?s=100" width="100px;" alt="Katie Murphy"/><br /><sub><b>Katie Murphy</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=kmurphy61" title="Documentation">📖</a> <a href="#tutorial-kmurphy61" title="Tutorials">✅</a> <a href="#talk-kmurphy61" title="Talks">📢</a> <a href="#ideas-kmurphy61" title="Ideas, Planning, & Feedback">🤔</a> <a href="#promotion-kmurphy61" title="Promotion">📣</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/k034b363"><img src="https://avatars.githubusercontent.com/u/156026125?v=4?s=100" width="100px;" alt="KeelyBrown"/><br /><sub><b>KeelyBrown</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=k034b363" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=k034b363" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=k034b363" title="Tests">⚠️</a> <a href="#tutorial-k034b363" title="Tutorials">✅</a> <a href="#ideas-k034b363" title="Ideas, Planning, & Feedback">🤔</a> <a href="#mentoring-k034b363" title="Mentoring">🧑‍🏫</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://gehan-lab.org"><img src="https://avatars.githubusercontent.com/u/6978303?v=4?s=100" width="100px;" alt="Malia Gehan"/><br /><sub><b>Malia Gehan</b></sub></a><br /><a href="#projectManagement-maliagehan" title="Project Management">📆</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=maliagehan" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=maliagehan" title="Documentation">📖</a> <a href="#fundingFinding-maliagehan" title="Funding Finding">🔍</a> <a href="#mentoring-maliagehan" title="Mentoring">🧑‍🏫</a> <a href="#talk-maliagehan" title="Talks">📢</a> <a href="#tutorial-maliagehan" title="Tutorials">✅</a> <a href="#ideas-maliagehan" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-maliagehan" title="Answering Questions">💬</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=maliagehan" title="Tests">⚠️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/maldil"><img src="https://avatars.githubusercontent.com/u/20140049?v=4?s=100" width="100px;" alt="Malinda"/><br /><sub><b>Malinda</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=maldil" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://www.marcusgriffiths.com"><img src="https://avatars.githubusercontent.com/u/44459040?v=4?s=100" width="100px;" alt="Marcus Griffiths"/><br /><sub><b>Marcus Griffiths</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=marcusdgriff" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=marcusdgriff" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=marcusdgriff" title="Tests">⚠️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/afinit"><img src="https://avatars.githubusercontent.com/u/6353304?v=4?s=100" width="100px;" alt="Mark Wilson"/><br /><sub><b>Mark Wilson</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=afinit" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=afinit" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=afinit" title="Tests">⚠️</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/mlohbihler"><img src="https://avatars.githubusercontent.com/u/1182059?v=4?s=100" width="100px;" alt="Matthew Lohbihler"/><br /><sub><b>Matthew Lohbihler</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/issues?q=author%3Amlohbihler" title="Bug reports">🐛</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=mlohbihler" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/maxjfeldman"><img src="https://avatars.githubusercontent.com/u/6977566?v=4?s=100" width="100px;" alt="Max"/><br /><sub><b>Max</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=maxjfeldman" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=maxjfeldman" title="Documentation">📖</a> <a href="#ideas-maxjfeldman" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/NMiklave"><img src="https://avatars.githubusercontent.com/u/50243212?v=4?s=100" width="100px;" alt="NMiklave"/><br /><sub><b>NMiklave</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=NMiklave" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="http://danforthcenter.org"><img src="https://avatars.githubusercontent.com/u/6233508?v=4?s=100" width="100px;" alt="Noah Fahlgren"/><br /><sub><b>Noah Fahlgren</b></sub></a><br /><a href="#projectManagement-nfahlgren" title="Project Management">📆</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=nfahlgren" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=nfahlgren" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=nfahlgren" title="Tests">⚠️</a> <a href="#fundingFinding-nfahlgren" title="Funding Finding">🔍</a> <a href="#mentoring-nfahlgren" title="Mentoring">🧑‍🏫</a> <a href="#talk-nfahlgren" title="Talks">📢</a> <a href="#tutorial-nfahlgren" title="Tutorials">✅</a> <a href="#ideas-nfahlgren" title="Ideas, Planning, & Feedback">🤔</a> <a href="#question-nfahlgren" title="Answering Questions">💬</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/Sam-Taylor-UIOWA"><img src="https://avatars.githubusercontent.com/u/116521490?v=4?s=100" width="100px;" alt="Samuel Kalevi Zebarth Taylor"/><br /><sub><b>Samuel Kalevi Zebarth Taylor</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=Sam-Taylor-UIOWA" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=Sam-Taylor-UIOWA" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/Sanazjd"><img src="https://avatars.githubusercontent.com/u/40071989?v=4?s=100" width="100px;" alt="Sanazjd"/><br /><sub><b>Sanazjd</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=Sanazjd" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=Sanazjd" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=Sanazjd" title="Tests">⚠️</a> <a href="#ideas-Sanazjd" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/SethPolydore"><img src="https://avatars.githubusercontent.com/u/65034463?v=4?s=100" width="100px;" alt="SethPolydore"/><br /><sub><b>SethPolydore</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=SethPolydore" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=SethPolydore" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=SethPolydore" title="Tests">⚠️</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://orcid.org/0000-0002-1338-8900"><img src="https://avatars.githubusercontent.com/u/2046665?v=4?s=100" width="100px;" alt="Steen Hoyer"/><br /><sub><b>Steen Hoyer</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=jshoyer" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=jshoyer" title="Documentation">📖</a> <a href="#ideas-jshoyer" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/stiphyMT"><img src="https://avatars.githubusercontent.com/u/15986230?v=4?s=100" width="100px;" alt="Stephan Summerer"/><br /><sub><b>Stephan Summerer</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=stiphyMT" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/stevenhwu"><img src="https://avatars.githubusercontent.com/u/1005078?v=4?s=100" width="100px;" alt="Steven Wu"/><br /><sub><b>Steven Wu</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=stevenhwu" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/Stylopidae1793"><img src="https://avatars.githubusercontent.com/u/128506162?v=4?s=100" width="100px;" alt="Stylopidae1793"/><br /><sub><b>Stylopidae1793</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=Stylopidae1793" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/Sunitalama2"><img src="https://avatars.githubusercontent.com/u/195969937?v=4?s=100" width="100px;" alt="Sunitalama2"/><br /><sub><b>Sunitalama2</b></sub></a><br /><a href="#tutorial-Sunitalama2" title="Tutorials">✅</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=Sunitalama2" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://tj-schultz.github.io/"><img src="https://avatars.githubusercontent.com/u/73593696?v=4?s=100" width="100px;" alt="TJ Schultz"/><br /><sub><b>TJ Schultz</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=tj-schultz" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/issues?q=author%3Atj-schultz" title="Bug reports">🐛</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://onlinegdb.com/h-5zNv0Dz"><img src="https://avatars.githubusercontent.com/u/114114550?v=4?s=100" width="100px;" alt="ZhakeYa D'Nai Hawkins"/><br /><sub><b>ZhakeYa D'Nai Hawkins</b></sub></a><br /><a href="#tutorial-zhaYdamenaceee" title="Tutorials">✅</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/abrown-37"><img src="https://avatars.githubusercontent.com/u/82683033?v=4?s=100" width="100px;" alt="abrown-37"/><br /><sub><b>abrown-37</b></sub></a><br /><a href="#ideas-abrown-37" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/adrianethompson"><img src="https://avatars.githubusercontent.com/u/85243018?v=4?s=100" width="100px;" alt="adrianethompson"/><br /><sub><b>adrianethompson</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=adrianethompson" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=adrianethompson" title="Documentation">📖</a> <a href="#tutorial-adrianethompson" title="Tutorials">✅</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/annacasto"><img src="https://avatars.githubusercontent.com/u/61164490?v=4?s=100" width="100px;" alt="annacasto"/><br /><sub><b>annacasto</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=annacasto" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=annacasto" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=annacasto" title="Tests">⚠️</a> <a href="#tutorial-annacasto" title="Tutorials">✅</a> <a href="#talk-annacasto" title="Talks">📢</a> <a href="#ideas-annacasto" title="Ideas, Planning, & Feedback">🤔</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/bganglia"><img src="https://avatars.githubusercontent.com/u/48276939?v=4?s=100" width="100px;" alt="bganglia"/><br /><sub><b>bganglia</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=bganglia" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=bganglia" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=bganglia" title="Tests">⚠️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/eseigeldanf"><img src="https://avatars.githubusercontent.com/u/195968072?v=4?s=100" width="100px;" alt="eseigeldanf"/><br /><sub><b>eseigeldanf</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/issues?q=author%3Aeseigeldanf" title="Bug reports">🐛</a> <a href="#tutorial-eseigeldanf" title="Tutorials">✅</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=eseigeldanf" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/ghernandez-57"><img src="https://avatars.githubusercontent.com/u/170016226?v=4?s=100" width="100px;" alt="ghernandez-57"/><br /><sub><b>ghernandez-57</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=ghernandez-57" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=ghernandez-57" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/jbraley1107"><img src="https://avatars.githubusercontent.com/u/186077704?v=4?s=100" width="100px;" alt="jbraley1107"/><br /><sub><b>jbraley1107</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/pulls?q=is%3Apr+reviewed-by%3Ajbraley1107" title="Reviewed Pull Requests">👀</a> <a href="#userTesting-jbraley1107" title="User Testing">📓</a> <a href="https://github.com/danforthcenter/plantcv/issues?q=author%3Ajbraley1107" title="Bug reports">🐛</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/jgerardhodge"><img src="https://avatars.githubusercontent.com/u/11335765?v=4?s=100" width="100px;" alt="jgerardhodge"/><br /><sub><b>jgerardhodge</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=jgerardhodge" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=jgerardhodge" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=jgerardhodge" title="Tests">⚠️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/jmgordon1223"><img src="https://avatars.githubusercontent.com/u/128613726?v=4?s=100" width="100px;" alt="jmgordon1223"/><br /><sub><b>jmgordon1223</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=jmgordon1223" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/jwheeler5"><img src="https://avatars.githubusercontent.com/u/86489506?v=4?s=100" width="100px;" alt="jwheeler5"/><br /><sub><b>jwheeler5</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=jwheeler5" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=jwheeler5" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=jwheeler5" title="Tests">⚠️</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/kbgilbert"><img src="https://avatars.githubusercontent.com/u/13541110?v=4?s=100" width="100px;" alt="kbgilbert"/><br /><sub><b>kbgilbert</b></sub></a><br /><a href="#design-kbgilbert" title="Design">🎨</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/lacostag"><img src="https://avatars.githubusercontent.com/u/72940710?v=4?s=100" width="100px;" alt="lacostag"/><br /><sub><b>lacostag</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=lacostag" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/lchavez037"><img src="https://avatars.githubusercontent.com/u/18586794?v=4?s=100" width="100px;" alt="lchavez037"/><br /><sub><b>lchavez037</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=lchavez037" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/leowlima"><img src="https://avatars.githubusercontent.com/u/123584304?v=4?s=100" width="100px;" alt="leowlima"/><br /><sub><b>leowlima</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=leowlima" title="Documentation">📖</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/mtwatso2-eng"><img src="https://avatars.githubusercontent.com/u/55025422?v=4?s=100" width="100px;" alt="mtwatso2-eng"/><br /><sub><b>mtwatso2-eng</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=mtwatso2-eng" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/natejly"><img src="https://avatars.githubusercontent.com/u/141955513?v=4?s=100" width="100px;" alt="natejly"/><br /><sub><b>natejly</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=natejly" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/scallen81"><img src="https://avatars.githubusercontent.com/u/21960021?v=4?s=100" width="100px;" alt="scallen81"/><br /><sub><b>scallen81</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=scallen81" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/sdkenney42"><img src="https://avatars.githubusercontent.com/u/128510721?v=4?s=100" width="100px;" alt="sdkenney42"/><br /><sub><b>sdkenney42</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=sdkenney42" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/trogers623"><img src="https://avatars.githubusercontent.com/u/195968055?v=4?s=100" width="100px;" alt="trogers623"/><br /><sub><b>trogers623</b></sub></a><br /><a href="#tutorial-trogers623" title="Tutorials">✅</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=trogers623" title="Documentation">📖</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/typelogic"><img src="https://avatars.githubusercontent.com/u/45341970?v=4?s=100" width="100px;" alt="typelogic"/><br /><sub><b>typelogic</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=typelogic" title="Code">💻</a></td>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/wurDevTim"><img src="https://avatars.githubusercontent.com/u/81219429?v=4?s=100" width="100px;" alt="wurDevTim"/><br /><sub><b>wurDevTim</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=wurDevTim" title="Code">💻</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=wurDevTim" title="Documentation">📖</a> <a href="https://github.com/danforthcenter/plantcv/commits?author=wurDevTim" title="Tests">⚠️</a></td>
    </tr>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://github.com/zeeuqsze"><img src="https://avatars.githubusercontent.com/u/107494588?v=4?s=100" width="100px;" alt="zeeuqsze"/><br /><sub><b>zeeuqsze</b></sub></a><br /><a href="https://github.com/danforthcenter/plantcv/commits?author=zeeuqsze" title="Documentation">📖</a> <a href="#tutorial-zeeuqsze" title="Tutorials">✅</a> <a href="#talk-zeeuqsze" title="Talks">📢</a> <a href="#mentoring-zeeuqsze" title="Mentoring">🧑‍🏫</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
